@@ -1,15 +1,16 @@
 import os
 import sys
 import json
+import yaml
 import shutil
 import tarfile
 import argparse
 import numpy as np
 import multiprocessing
-from typing import List
+from typing import List, Dict
 from contextlib import contextmanager
 
-from hpogrid.components.defaults import *  
+from hpogrid.components.defaults import *
 
 class NpEncoder(json.JSONEncoder):
     def default(self, obj):
@@ -75,13 +76,30 @@ def get_project_path(proj_name):
         raise RuntimeError('Project "{}" not found.'.format(proj_name))
     return proj_path
 
+def load_configuration(config_input:[Dict, str]) -> Dict:
+    if isinstance(config_input, dict):
+        return config_input
+    elif isinstance(config_input, str):
+        with open(config_input, 'r') as file:
+            ext = os.path.splitext(config_input)[1]
+            if ext in ['.txt', '.yaml']:
+                config = yaml.safe_load(file)
+            elif ext == '.json':
+                config = json.load(file)
+            else:
+                raise ValueErrror('The configuration file has an unsupported '
+                              'file extension: {}\n Supported file extensions '
+                              'are .txt, .yaml or .json'.format(ext))
+        return config
+    else:
+        raise ValueError('Unknown configuration format: {}'.format(type(config_input)))
+
 def get_project_config(proj_name):
     project_path = get_project_path(proj_name)
     config_path = os.path.join(project_path, 'config', kProjectConfigNameJson)
     if not os.path.exists(config_path):
         raise FileNotFoundError('Missing project configuration file: {}'.format(config_path))
-    with open(config_path) as config_file:
-        config = json.load(config_file)
+    config = load_configuration(config_path)
     return config
 
 @contextmanager
@@ -99,8 +117,8 @@ def get_physical_devices(device_type='GPU'):
     return physical_devices
 
 def get_n_gpu():
-    physical_devices = get_physical_devices('GPU')
-    return len(physical_devices)
+    import torch
+    return torch.cuda.device_count()
 
 def get_n_cpu():
     return multiprocessing.cpu_count()
